#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=hawthorne5.5_sel1.ps
projection=-JM16.0c+
region=-R-118.2/-117.8/38.1/38.3
gmt psbasemap $region $projection -Bxa0.2f0.1 -Bya0.2f0.1 -BWeSn+t'Base Map hawthorne5.5' -K > $psfile
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile
# Event numbers
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    38.152  -117.874
END
gmt psxy -: -R $projection -Sl8p+t"94" -G0 -O -K << END >> $psfile
    38.166  -118.066
END
gmt psxy -: -R $projection -Sl8p+t"95" -G0 -O -K << END >> $psfile
    38.180  -118.058
END
gmt psxy -: -R $projection -Sl8p+t"96" -G0 -O -K << END >> $psfile
    38.169  -118.077
END
gmt psxy -: -R $projection -Sl8p+t"97" -G0 -O -K << END >> $psfile
    38.179  -118.057
END
gmt psxy -: -R $projection -Sl8p+t"98" -G0 -O -K << END >> $psfile
    38.179  -118.072
END
gmt psxy -: -R $projection -Sl8p+t"99" -G0 -O -K << END >> $psfile
    38.175  -118.062
END
# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.152  -117.874
    38.152  -117.874
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.163  -117.859
    38.152  -117.874
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.166  -118.065
    38.166  -118.066
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.171  -118.064
    38.166  -118.066
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.180  -118.058
    38.180  -118.058
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.185  -118.059
    38.180  -118.058
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.170  -118.076
    38.169  -118.077
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.155  -118.074
    38.169  -118.077
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.178  -118.057
    38.179  -118.057
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.194  -118.046
    38.179  -118.057
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.179  -118.071
    38.179  -118.072
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.176  -118.071
    38.179  -118.072
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    38.175  -118.062
    38.175  -118.062
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    38.178  -118.075
    38.175  -118.062
END
# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    38.152  -117.874   -40.309     0.569     0.960
    38.166  -118.066   -40.791     0.707     1.255
    38.180  -118.058   -33.156     0.755     1.280
    38.169  -118.077   -40.231     0.831     1.657
    38.179  -118.057   -43.275     0.841     1.304
    38.179  -118.072   -45.478     2.153     4.845
    38.175  -118.062   -36.400     0.807     1.342
END
# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    38.152  -117.874     0.200
END

# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    38.106  -118.109   -61.939     0.498     0.632
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    38.106  -118.086   Hypocentroid
END
# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    38.106  -118.109     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    38.106  -118.109     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    38.061  -118.109   5 km
END
